@@ -13,10 +13,13 @@ def main():
     #Generate Model
     model_ = Model(components, beam_z = 0.6, beam_type = 'paralell', num_rays = 128)
     
+    viewer = run_pyqt(model_)  
     
-    run_pyqt(model_)
-        
+    return viewer
+
 if __name__ == '__main__':
+    
     AppWindow = QApplication(sys.argv)
-    main()
-    sys.exit(AppWindow.exec_())
+    viewer = main()    
+    viewer.show()
+    AppWindow.exec_()
\ No newline at end of file
