@@ -4,7 +4,6 @@ from temgymbasic.run import run_pyqt
 from PyQt5.QtWidgets import QApplication
 import sys 
 
-
 def main():
     components = [comp.Lens(name = '1st Condenser Lens', z = 1.5, f = -0.1),
                   comp.Aperture(name = 'Spray Aperture', z = 1.2, aperture_radius_inner = 0.05),
@@ -17,9 +16,15 @@ def main():
     
     model_ = Model(components, beam_z = 1.7, beam_type = 'point', 
                        num_rays = 256, beam_semi_angle = 0.15)
-    run_pyqt(model_)
+    
+    viewer = run_pyqt(model_)   
+    
+    return viewer 
 
 if __name__ == '__main__':
+    
     AppWindow = QApplication(sys.argv)
-    main()
-    sys.exit(AppWindow.exec_())
\ No newline at end of file
+    
+    viewer = main()
+    viewer.show()
+    AppWindow.exec_()
\ No newline at end of file
